==> keycloak-model-map-17.0.1-sources.jar: org/keycloak/models/map/authorization/entity/MapResourceEntityDelegate.java <==
package org.keycloak.models.map.authorization.entity;
public class MapResourceEntityDelegate implements org.keycloak.models.map.authorization.entity.MapResourceEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapResourceEntity> delegateProvider;
    public MapResourceEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapResourceEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public java.util.Map<String,java.util.List<String>> getAttributes() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES).getAttributes();
    }
    @Override public void setAttributes(java.util.Map<String,java.util.List<String>> attributes) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES, attributes).setAttributes(attributes);
    }
    @Override public java.util.List<String> getAttribute(String name) {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES, name).getAttribute(name);
    }
    @Override public void setAttribute(String name, java.util.List<String> value) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES, name, value).setAttribute(name, value);
    }
    @Override public void removeAttribute(String name) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES, name).removeAttribute(name);
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ID, id).setId(id);
    }
    @Override public String getName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.NAME).getName();
    }
    @Override public void setName(String name) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.NAME, name).setName(name);
    }
    @Override public String getDisplayName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.DISPLAY_NAME).getDisplayName();
    }
    @Override public void setDisplayName(String displayName) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.DISPLAY_NAME, displayName).setDisplayName(displayName);
    }
    @Override public java.util.Set<String> getUris() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.URIS).getUris();
    }
    @Override public void setUris(java.util.Set<String> uris) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.URIS, uris).setUris(uris);
    }
    @Override public String getType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.TYPE).getType();
    }
    @Override public void setType(String type) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.TYPE, type).setType(type);
    }
    @Override public String getIconUri() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ICON_URI).getIconUri();
    }
    @Override public void setIconUri(String iconUri) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ICON_URI, iconUri).setIconUri(iconUri);
    }
    @Override public String getOwner() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.OWNER).getOwner();
    }
    @Override public void setOwner(String owner) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.OWNER, owner).setOwner(owner);
    }
    @Override public Boolean isOwnerManagedAccess() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.OWNER_MANAGED_ACCESS).isOwnerManagedAccess();
    }
    @Override public void setOwnerManagedAccess(Boolean ownerManagedAccess) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.OWNER_MANAGED_ACCESS, ownerManagedAccess).setOwnerManagedAccess(ownerManagedAccess);
    }
    @Override public void setResourceServerId(String resourceServerId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.RESOURCE_SERVER_ID, resourceServerId).setResourceServerId(resourceServerId);
    }
    @Override public String getResourceServerId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.RESOURCE_SERVER_ID).getResourceServerId();
    }
    @Override public java.util.Set<String> getScopeIds() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.SCOPE_IDS).getScopeIds();
    }
    @Override public void setScopeIds(java.util.Set<String> scopeIds) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.SCOPE_IDS, scopeIds).setScopeIds(scopeIds);
    }
}

==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/authorization/entity/MapResourceEntityDelegate.java <==
package org.keycloak.models.map.authorization.entity;
public class MapResourceEntityDelegate implements org.keycloak.models.map.authorization.entity.MapResourceEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapResourceEntity> delegateProvider;
    public MapResourceEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapResourceEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public java.util.Map<String,java.util.List<String>> getAttributes() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES).getAttributes();
    }
    @Override public void setAttributes(java.util.Map<String,java.util.List<String>> attributes) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES, attributes).setAttributes(attributes);
    }
    @Override public java.util.List<String> getAttribute(String name) {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES, name).getAttribute(name);
    }
    @Override public void setAttribute(String name, java.util.List<String> value) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES, name, value).setAttribute(name, value);
    }
    @Override public void removeAttribute(String name) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ATTRIBUTES, name).removeAttribute(name);
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ID, id).setId(id);
    }
    @Override public String getRealmId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.REALM_ID).getRealmId();
    }
    @Override public void setRealmId(String realmId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.REALM_ID, realmId).setRealmId(realmId);
    }
    @Override public String getName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.NAME).getName();
    }
    @Override public void setName(String name) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.NAME, name).setName(name);
    }
    @Override public String getDisplayName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.DISPLAY_NAME).getDisplayName();
    }
    @Override public void setDisplayName(String displayName) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.DISPLAY_NAME, displayName).setDisplayName(displayName);
    }
    @Override public java.util.Set<String> getUris() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.URIS).getUris();
    }
    @Override public void setUris(java.util.Set<String> uris) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.URIS, uris).setUris(uris);
    }
    @Override public String getType() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.TYPE).getType();
    }
    @Override public void setType(String type) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.TYPE, type).setType(type);
    }
    @Override public String getIconUri() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ICON_URI).getIconUri();
    }
    @Override public void setIconUri(String iconUri) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.ICON_URI, iconUri).setIconUri(iconUri);
    }
    @Override public String getOwner() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.OWNER).getOwner();
    }
    @Override public void setOwner(String owner) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.OWNER, owner).setOwner(owner);
    }
    @Override public Boolean isOwnerManagedAccess() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.OWNER_MANAGED_ACCESS).isOwnerManagedAccess();
    }
    @Override public void setOwnerManagedAccess(Boolean ownerManagedAccess) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.OWNER_MANAGED_ACCESS, ownerManagedAccess).setOwnerManagedAccess(ownerManagedAccess);
    }
    @Override public void setResourceServerId(String resourceServerId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.RESOURCE_SERVER_ID, resourceServerId).setResourceServerId(resourceServerId);
    }
    @Override public String getResourceServerId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.RESOURCE_SERVER_ID).getResourceServerId();
    }
    @Override public java.util.Set<String> getScopeIds() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.SCOPE_IDS).getScopeIds();
    }
    @Override public void setScopeIds(java.util.Set<String> scopeIds) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapResourceEntityFields.SCOPE_IDS, scopeIds).setScopeIds(scopeIds);
    }
}
